# sarvamai


<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

This file will become your README and also the index of your
documentation.

## Developer Guide

If you are new to using `nbdev` here are some useful pointers to get you
started.

### Install sarvamai in Development mode

``` sh
# make sure sarvamai package is installed in development mode
$ pip install sarvamai

# make changes under nbs/ directory
# ...

# compile to have changes apply to sarvamai
$ nbdev_prepare
```

## Usage

### Installation

Install latest from the GitHub
[repository](https://github.com/kurianbenoy-sarvam/sarvamai):

``` sh
$ pip install git+https://github.com/kurianbenoy-sarvam/sarvamai.git
```

or from [conda](https://anaconda.org/kurianbenoy-sarvam/sarvamai)

``` sh
$ conda install -c kurianbenoy-sarvam sarvamai
```

or from [pypi](https://pypi.org/project/sarvamai/)

``` sh
$ pip install sarvamai
```

### Documentation

Documentation can be found hosted on this GitHub
[repository](https://github.com/kurianbenoy-sarvam/sarvamai)’s
[pages](https://kurianbenoy-sarvam.github.io/sarvamai/). Additionally
you can find package manager specific guidelines on
[conda](https://anaconda.org/kurianbenoy-sarvam/sarvamai) and
[pypi](https://pypi.org/project/sarvamai/) respectively.

## How to use

Fill me in please! Don’t forget code examples:

``` python
1+1
```

    2
